@@ -244,10 +244,10 @@ impl<T: 'static + ?Sized> CosyncQueueHandle<T> {
 // as Cosync, so we should never have a problem with multithreaded access
 // at the same time.
 #[allow(clippy::non_send_fields_in_send_ty)]
-unsafe impl<T> Send for CosyncQueueHandle<T> {}
-unsafe impl<T> Sync for CosyncQueueHandle<T> {}
+unsafe impl<T: ?Sized> Send for CosyncQueueHandle<T> {}
+unsafe impl<T: ?Sized> Sync for CosyncQueueHandle<T> {}
 
-impl<T> Clone for CosyncQueueHandle<T> {
+impl<T: ?Sized> Clone for CosyncQueueHandle<T> {
     fn clone(&self) -> Self {
         Self {
             heap_ptr: self.heap_ptr,
@@ -293,6 +293,11 @@ impl<T: 'static + ?Sized> CosyncInput<T> {
     {
         self.0.queue(task)
     }
+
+    /// Creates a queue handle which can be used to spawn tasks.
+    pub fn create_queue_handle(&self) -> CosyncQueueHandle<T> {
+        self.0.clone()
+    }
 }
 
 // safety:
@@ -740,4 +745,18 @@ mod tests {
             println!("inner str = {}", inner_str);
         });
     }
+
+    #[test]
+    fn can_move_non_copy() {
+        let mut cosync: Cosync<i32> = Cosync::new();
+
+        let my_vec = vec![10];
+
+        cosync.queue(|_input| async move {
+            let mut vec = my_vec;
+            vec.push(10);
+
+            assert_eq!(*vec, [10, 10]);
+        });
+    }
 }
